Crate mermaid_runtime

Crate mermaid_runtime 

Daemon-safe runtime services.

The TUI reducer remains the correctness core, but durable concerns that a daemon or future remote client will also need live here. The first slice is SQLite-backed state for tasks, approvals, processes, and the future provider/memory/checkpoint tables.

Re-exports

pub use approval::ApprovalReplayResult;
pub use approval::approve_and_replay;
pub use approval::deny_approval;
pub use checkpoint::CheckpointFile;
pub use checkpoint::CheckpointManifest;
pub use checkpoint::create_checkpoint;
pub use checkpoint::create_checkpoint_for_task;
pub use checkpoint::restore_checkpoint;
pub use daemon::daemon_socket_path;
pub use daemon::generate_pairing_token;
pub use daemon::hash_pairing_token;
pub use daemon::request_daemon_json;
pub use daemon::request_daemon_text;
pub use daemon::snapshot_field_from_daemon;
pub use plugin::PluginManifest;
pub use plugin::PluginPermissionPreview;
pub use plugin::install_plugin_from_path;
pub use plugin::plugin_permission_preview;
pub use plugin::run_plugin_hooks;
pub use plugin::validate_plugin_manifest;
pub use plugin::write_plugin_lockfile;
pub use policy::ActionRequest;
pub use policy::PolicyDecision;
pub use policy::PolicyEngine;
pub use policy::PolicyOverride;
pub use policy::PolicyOverrideDecision;
pub use policy::RiskClass;
pub use policy::SafetyMode;
pub use policy::ToolCategory;
pub use storage::ApprovalRecord;
pub use storage::ApprovalsRepo;
pub use storage::CheckpointRecord;
pub use storage::CheckpointsRepo;
pub use storage::CompactionRecord;
pub use storage::CompactionsRepo;
pub use storage::MessageRecord;
pub use storage::MessagesRepo;
pub use storage::NewApproval;
pub use storage::NewCheckpoint;
pub use storage::NewCompaction;
pub use storage::NewMessage;
pub use storage::NewPluginInstall;
pub use storage::NewProcess;
pub use storage::NewProviderProbe;
pub use storage::NewSession;
pub use storage::NewTask;
pub use storage::NewToolRun;
pub use storage::PairingTokenRecord;
pub use storage::PairingTokensRepo;
pub use storage::PluginInstallRecord;
pub use storage::PluginsRepo;
pub use storage::ProcessRecord;
pub use storage::ProcessStatus;
pub use storage::ProcessesRepo;
pub use storage::ProviderProbeRecord;
pub use storage::ProviderProbesRepo;
pub use storage::RuntimeStore;
pub use storage::SessionRecord;
pub use storage::SessionsRepo;
pub use storage::TaskPriority;
pub use storage::TaskRecord;
pub use storage::TaskStatus;
pub use storage::TaskTimelineEvent;
pub use storage::TasksRepo;
pub use storage::ToolRunRecord;
pub use storage::ToolRunsRepo;
pub use storage::data_dir;

Modules

approval
checkpoint
daemon
plugin
policy
storage